@@ -145,6 +145,36 @@ def parse_string(annotation_string: str) -> Document:
     return Document(entities, relations, attributes)
 
 
+def parse_string_to_augmented_entities(
+    annotation_string: str,
+) -> Dict[str, AugmentedEntity]:
+    document = parse_string(annotation_string)
+    augmented_entities: Dict[str, AugmentedEntity] = {}
+    for entity in document.entities:
+        entity_id = entity.id
+        entity_relations_from_me = []
+        entity_relations_to_me = []
+        entity_attributes = []
+        for relation in document.relations:
+            if relation.subj == entity_id:
+                entity_relations_from_me.append(relation)
+            if relation.obj == entity_id:
+                entity_relations_to_me.append(relation)
+        for attribute in document.attributes:
+            if attribute.target == entity_id:
+                entity_attributes.append(attribute)
+        augmented_entities[entity.id] = AugmentedEntity(
+            id=entity.id,
+            type=entity.type,
+            span=entity.span,
+            text=entity.text,
+            relations_from_me=tuple(entity_relations_from_me),
+            relations_to_me=tuple(entity_relations_to_me),
+            attributes=tuple(entity_attributes),
+        )
+    return augmented_entities
+
+
 def get_augmented_entities(ann_path: str) -> Dict[str, AugmentedEntity]:
     entities, relations, attributes, _ = get_entities_relations_attributes_groups(
         ann_path
